@@ -2,8 +2,6 @@
 /*
  * This file bootstraps the test environment.
  */
-namespace Doctrine\Tests;
-
 error_reporting(E_ALL | E_STRICT);
 
 if (file_exists(__DIR__ . '/../../../vendor/autoload.php')) {
@@ -13,7 +11,7 @@ if (file_exists(__DIR__ . '/../../../vendor/autoload.php')) {
     // installed as a dependency in `vendor`
     $classLoader = require __DIR__ . '/../../../../../autoload.php';
 } else {
-    throw new \Exception('Can\'t find autoload.php. Did you install dependencies via composer?');
+    throw new Exception('Can\'t find autoload.php. Did you install dependencies via Composer?');
 }
 
 /* @var $classLoader \Composer\Autoload\ClassLoader */
